@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.shortcuts import render
 
+
 # from django.template.context import RequestContext
 
 
@@ -8,4 +9,4 @@ def home(request):
     """
     home page
     """
-    return render(request, 'home.html')
+    return render(request, "home.html")
